<?php
namespace App\Common;

use App\Http\Requests;
use Illuminate\Support\Facades\Log;

class Api{

    /**
     * 接口返回信息json转化
     * @param null $code
     * @param null $msg
     * @param array $data
     * @return string
     */
    public static function json($code=NULL, $msg=NULL, $data=array()){
        if(isset($code)){
            $res['error'] = $code;
        }
        if($msg){
            $res['message'] = $msg;
        }

        if(empty($data)){
            $res['data'] = [];
        } else {
            $res['data'] = $data;
        }


        return json_encode($res);
    }

    /**
     * 分页数据格式化
     * @param $info
     * @return array
     */
    public static function page($info){
        $info = collect($info)->toArray();

        $data = [];
        $data['total']      = $info['total'];
        $data['total_page'] = $info['last_page'];
        $data['page']       = $info['current_page'];
        $data['page_size']  = $info['per_page'];
        $data['data']       = $info['data'];

        return $data;
    }

    /**
     * 接口数据数组化
     * @param $code
     * @param $msg
     * @param string $data
     * @return array
     */
    public static function arr($code, $msg, $data=''){
        $res = [];
        if(isset($code)){
            $res['code'] = $code;
        }
        if($msg){
            $res['msg'] = $msg;
        }
        $res['data'] = $data;
        return $res;
    }

    /**
     * 日期时间数据格式化
     * @param $data
     * @return mixed
     */
    public static function dateFormat($data){
        collect($data)->toArray();

        if(isset($data['update_time']) && !empty($data['update_time'])){
            $data['update_time'] = date('Y-m-d H:i:s', $data['update_time']);
        }
        if(isset($data['create_time']) && !empty($data['create_time'])){
            $data['create_time'] = date('Y-m-d H:i:s', $data['create_time']);
        }
        if(isset($data['start_time']) && !empty($data['start_time'])){
            $data['start_time'] = date('Y-m-d H:i:s', $data['start_time']);
        }
        if(isset($data['end_time']) && !empty($data['end_time'])){
            $data['end_time'] = date('Y-m-d H:i:s', $data['end_time']);
        }
        return $data;
    }

    /**
     * 请求外部链接
     * @param $url
     * @param string $post
     */
    public static function curl($url, $post=''){
        $ch = curl_init();
        $timeout = 5;
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);

        if($post){
            curl_setopt($ch, CURLOPT_POST,true);
        }

        $contents = curl_exec($ch);
        curl_close($ch);

        return $contents;
    }

    /**
     * 去除字符串中的空格
     * @param $str
     * @return mixed
     */
    public static function trimAll($str){
        $null_str=array(" ","　","\t","\n","\r");
        $replace_str=array("","","","","");
        return str_replace($null_str,$replace_str,$str);
    }

    /**
     * 服务器错误处理
     * @param $e
     * @return string
     */
    public static function serviceError($e){
        Log::info($e);
        return self::json(config('code.service_error'), trans('msg.service_error'));
    }

    /**
     * unicode转码为utf-8
     * 用于去除电话号码中隐藏的unicode编码
     * @param $name
     * @return string
     */
    public static function unicode_decode($ostr)
    {
        $json = '{"str":"'.$ostr.'"}';
        $arr = json_decode($json,true);
        if(empty($arr)) return '';

        preg_match_all('/[\x{FF00}-\x{FFEF}|\x{0000}-\x{00ff}|\x{4e00}-\x{9fff}]+/u', $ostr, $matches);
        $str = join('', $matches[0]);
        if($str==''){   //含有特殊字符需要逐個處理
            $returnstr = '';
            $i = 0;
            $str_length = strlen($ostr);
            while ($i<=$str_length){
                $temp_str = substr($ostr, $i, 1);
                $ascnum = Ord($temp_str);
                if ($ascnum>=224){
                    $returnstr = $returnstr.substr($ostr, $i, 3);
                    $i = $i + 3;
                }elseif ($ascnum>=192){
                    $returnstr = $returnstr.substr($ostr, $i, 2);
                    $i = $i + 2;
                }elseif ($ascnum>=65 && $ascnum<=90){
                    $returnstr = $returnstr.substr($ostr, $i, 1);
                    $i = $i + 1;
                }elseif ($ascnum>=128 && $ascnum<=191){ // 特殊字符
                    $i = $i + 1;
                }else{
                    $returnstr = $returnstr.substr($ostr, $i, 1);
                    $i = $i + 1;
                }
            }
            $str = $returnstr;
            preg_match_all('/[\x{FF00}-\x{FFEF}|\x{0000}-\x{00ff}|\x{4e00}-\x{9fff}]+/u', $str, $matches);
            $str = join('', $matches[0]);
        }
        return $str;
        //return $arr['str'];
    }

    /**
     * 替换不见unicode字符
     * 用于去除guid和部门导入时的特殊字符
     * 添加保留符号时在中括号中添加
     * @param $str
     * @return mixed
     */
    public static function trimUnicode($str){
        $str = self::setFilter($str);
        $res = preg_replace('#[^\x{4e00}-\x{9fa5}A-Za-z0-9\-\_\(\)\[\]\{\}\<\>\*\=\+]#u','',$str);
        return $res;
    }

    /**
     * 全半角转换
     * @param $html
     * @return string
     */
    public static function setFilter($html){
        $arr = array('０' => '0', '１' => '1', '２' => '2', '３' => '3', '４' => '4',
            '５' => '5', '６' => '6', '７' => '7', '８' => '8', '９' => '9',
            'Ａ' => 'A', 'Ｂ' => 'B', 'Ｃ' => 'C', 'Ｄ' => 'D', 'Ｅ' => 'E',
            'Ｆ' => 'F', 'Ｇ' => 'G', 'Ｈ' => 'H', 'Ｉ' => 'I', 'Ｊ' => 'J',
            'Ｋ' => 'K', 'Ｌ' => 'L', 'Ｍ' => 'M', 'Ｎ' => 'N', 'Ｏ' => 'O',
            'Ｐ' => 'P', 'Ｑ' => 'Q', 'Ｒ' => 'R', 'Ｓ' => 'S', 'Ｔ' => 'T',
            'Ｕ' => 'U', 'Ｖ' => 'V', 'Ｗ' => 'W', 'Ｘ' => 'X', 'Ｙ' => 'Y',
            'Ｚ' => 'Z', 'ａ' => 'a', 'ｂ' => 'b', 'ｃ' => 'c', 'ｄ' => 'd',
            'ｅ' => 'e', 'ｆ' => 'f', 'ｇ' => 'g', 'ｈ' => 'h', 'ｉ' => 'i',
            'ｊ' => 'j', 'ｋ' => 'k', 'ｌ' => 'l', 'ｍ' => 'm', 'ｎ' => 'n',
            'ｏ' => 'o', 'ｐ' => 'p', 'ｑ' => 'q', 'ｒ' => 'r', 'ｓ' => 's',
            'ｔ' => 't', 'ｕ' => 'u', 'ｖ' => 'v', 'ｗ' => 'w', 'ｘ' => 'x',
            'ｙ' => 'y', 'ｚ' => 'z',
            '（' => '(', '）' => ')', '〔' => '[', '〕' => ']', '【' => '[',
            '】' => ']', '〖' => '[', '〗' => ']', '“' => '[', '”' => ']',
            '‘' => '[', '’' => ']', '｛' => '{', '｝' => '}', '《' => '<',
            '》' => '>',
            '％' => '%', '＋' => '+', '—' => '-', '－' => '-', '～' => '-',
            '：' => ':', '。' => '.', '、' => ',', '，' => '.', '、' => '.',
            '；' => ',', '？' => '?', '！' => '!', '…' => '-', '‖' => '|',
            '”' => '"', '’' => '`', '‘' => '`', '｜' => '|', '〃' => '"',
            '　' => ' ');
        return strtr($html, $arr);
    }
}?>