<?php

namespace App\Http\Controllers\Api;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use App\Common\Api;

use App\Models\Apps;
use App\Models\Activitys;
use App\Models\Corps;

use Illuminate\Support\Facades\Validator;
use Qiniu\Auth;
use Qiniu\Storage\UploadManager;

use App\Services\ActivityService;

use DB;
use Excel;

class ActivityController extends Controller
{

    public function __construct(){
        //加载中间键
        $this->middleware('CheckLogin');
        $this->middleware('Logs');
        $this->middleware('CacheClear');
    }

    //宝箱设置
    const LOTTERY_LEVEL = array(
        'copperPrize'=>1,
        'sliverPrize'=>2,
        'goldPrize'  =>3,
    );
    const USER_UPLOAD = 1;

    /**
     *  获取活动列表
     *  Corp_id int() 企业ID
     *  2018-05-08 16:55 韩
     */
    public function getActList(Request $request){
        try {
            $params = $request->all();

            $keys = array('corp_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_error'));
                }
            }

            $page_size = empty($params['page_size']) ? 10 : $params['page_size'];

            if (isset($params['keyword']) && !empty($params['keyword'])) {
                $data = Activitys::where('corp_id', $params['corp_id'])
                    ->where('status', '1')
                    ->where('is_complete_set', '1')
                    ->where('title', 'like', "%" . $params['keyword'] . "%")
                    ->orderByDesc("create_time")->paginate($page_size);
            } else {
                $data = Activitys::where('corp_id', $params['corp_id'])
                    ->where('status', '1')
                    ->where('is_complete_set', '1')
                    ->orderByDesc("create_time")->paginate($page_size);
            }

            $data = Api::page($data);

            foreach ($data['data'] as $k => $v) {
                //管理路由地址
                $app_info = Apps::where('app_id', $v['app_id'])->first()->toArray();
                $data['data'][$k]['admin_url'] = $app_info['admin_url'];

                //游戏路由地址
                $data['data'][$k]['game_url'] = env('WEB_URL') . '/' . $app_info['app_code'] . '?activity_id=' . $v['activity_id'];
            }

            //时间戳格式化
            foreach ($data['data'] as $key => $val) {
                $data['data'][$key] = Api::dateFormat($val);
                //活动状态
                if ($val['start_time'] > time()) {
                    $data['data'][$key]['activity_status_text'] = '未开始';
                } elseif ($val['end_time'] < time()) {
                    $data['data'][$key]['activity_status_text'] = '已结束';
                } else {
                    if ($val['is_temp_stop'] == 1) {
                        $data['data'][$key]['activity_status_text'] = '已暂停';
                    } else {
                        $data['data'][$key]['activity_status_text'] = '进行中';
                    }
                }
            }
            return Api::json(config('code.success'), trans('msg.success'), $data);

        } catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     *  获取活动详情
     *  act_id  int  活动ID
     */
    public function getActInfo(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'corp_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_error'));
                }
            }

            $res = ActivityService::getActivityInfo($params['activity_id'], $params['corp_id']);

            if ($res) {
                return Api::json(config('code.success'), trans('msg.success'), $res);
            } else {
                return Api::json(config('code.activity_not_exist'), trans('msg.activity_not_exist'));
            }
        } catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     *  应用列表
     *  corp_id 企业ID
     */
    public function getAppList(Request $request){
        try {
            $res = Apps::get();

            $data = json_decode($res, true);

            $params = $request->all();
            if (empty($params['corp_id'])) {
                return Api::json(config('code.params_error'), trans('msg.params_error'));
            }
            $userInfo = $request->session()->get('userInfo');
            //给超级管理员的企业ID赋值。赋予当前选中的企业ID
            if ($userInfo['is_admin'] == 1) {
                $userInfo['corp_id'] = $params['corp_id'];
                $request->session()->put('userInfo', $userInfo);
            }

            return Api::json(config('code.success'), trans('msg.success'), $data);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     *  获取应用详情
     *  id  int   活动类行ID
     */
    public function getAppInfo(Request $request){
        try {
            $params = $request->all();

            if (empty($params['app_id'])) {
                return Api::json(config('code.params_error'), trans('msg.params_error'));
            }

            $data = Apps::where('app_id', $params['app_id'])->first();

            return Api::json(config('code.success'), trans('msg.success'), $data);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     *  超级管理员获取企业列表
     *
     */
    public function getCorpList(Request $request){
        try {
            $params = $request->all();

            $page_size = empty($params['page_size']) ? 10 : $params['page_size'];

            $keyword = $request->get("keyword");

            if (is_null($keyword)) {
                $corp_info = Corps::orderByDesc("corp_id")->paginate($page_size);
            } else {
                $corp_info = Corps::where("corp_name", "like", "%" . $keyword . "%")
                    ->orderByDesc("corp_id")->paginate($page_size);
            }

            $data = Api::page($corp_info);

            //时间戳转换
            foreach ($data['data'] as $key => $val) {
                $data['data'][$key] = Api::dateFormat($val);
            }

            return Api::json(config('code.success'), trans('msg.success'), $data);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     *  获取七牛上传头token
     */
    public function getUploadToken(Request $request){
        try {
            $accessKey = env("QINIU_ACCESS_KEY");
            $secretKey = env("QINIU_SECRET_KEY");
            $auth = new Auth($accessKey, $secretKey);
            $bucket = env("QINIU_BUCKET");
            // 生成上传Token
            $token = $auth->uploadToken($bucket);

            $data['token'] = $token;
            return Api::json(config('code.success'), trans('msg.success'), $data);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 活动复制
     * @param Request $request
     * @return string
     */
    public function getActCopy(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            $res = ActivityService::copyActivity($params);

            if ($res) {
                $data['activity_id'] = $res;
                return Api::json(config('code.success'), trans('msg.success'), $data);
            } else {
                return Api::json(config('code.fail'), trans('msg.fail'));
            }
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 活动下架（删除）
     * @param Request $request
     * @return string
     */
    public function postChangeStatus(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'corp_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            $res = ActivityService::changeActStatus($params);

            return Api::json($res['code'], $res['msg']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 暂停活动
     * @param Request $request
     * @return string
     */
    public function getActStop(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'corp_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            $res = ActivityService::stopActivity($params);

            return Api::json($res['code'], $res['msg']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 新建活动
     * 2018-06-19 17:00:00
     * @param Request $request
     * @return string
     */
    public function postAddAct(Request $request){
        try {
            $params = $request->all();

            $keys = array('corp_id', 'app_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            if($params['activity_id']){
                $res = ActivityService::getConfigs($params['activity_id'], $params['corp_id']);
            } else {
                $res = ActivityService::addAct($params['corp_id'], $params['app_id']);
            }

            return Api::json($res['code'], $res['msg'], $res['data']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 保存活动
     * 2018-06-20 10:25:00
     * @param Request $request
     * @return string
     */
    public function postSaveAct(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'corp_id', 'app_id', 'title', 'start_time', 'end_time');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            //数字不能为小数点  不能为负数
            $int_key = array();

            $res = ActivityService::saveActivity($params);

            return Api::json($res['code'], $res['msg'], $res['data']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    public function postTest(Request $request){
    /*参数验证测试*/
////        $params = $request->validate([
////            'username'=>'required',
////            'password'=>'required',
////        ]);
//        $validator = Validator::make($request->all(), [
//            'username' => 'required |max:255',
//            'password' => 'required',
//        ]);
//
//        if ($validator->fails()) {
//            $errors = collect($validator->errors())->toArray();
//            $res = current($errors);
//            return Api::json(config('code.success'), trans('msg.success'), $res);
////            return $validator->errors();
//        }
//
//        return Api::json(config('code.success'), trans('msg.success'));

        return 'xxxx';
    }
}
?>





