<?php

namespace App\Http\Controllers\brainstorming;

use App\Common\Api;
use App\Models\LotteryBoxs;
use App\Services\ActivityService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use App\Services\PrizeService;

class PrizeController extends Controller
{
    public function __construct()
    {
        //加载中间键
//        $this->middleware('CheckLogin');
//        $this->middleware('Logs');
//        $this->middleware('CacheClear');
    }

    /**
     *  宝箱——添加/修改奖品
     */
    public function postSave(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'corp_id', 'lottery_level', 'prize_name', 'prize_day_rule', 'prize_count', 'prize_weights', 'prize_image_url');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            $res = PrizeService::prizeDetail($params);

            return Api::json($res['code'], $res['msg'], $res['data']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 获取宝箱内的奖品列表
     * @param Request $request
     * @return string
     */
    public function getList(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'lottery_level', 'corp_id');
            foreach ($keys as $key) {
                if (empty($params[$key])) {
                    return Api::json(config('code.params_error'), trans('params.'.$key) . trans('msg.params_not_null'));
                }
            }

            $res = PrizeService::getPrizeList($params['corp_id'], $params['activity_id'], $params['lottery_level']);

            return Api::json($res['code'], $res['msg'], $res['data']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 奖品删除或冻结
     * @param Request $request
     * @return string
     */
    public function postSoldOut(Request $request){
        try {
            $params = $request->all();

            $keys = array('activity_id', 'lottery_level', 'corp_id', 'prize_id', 'status');
            foreach ($keys as $key) {
                if (empty($params[$key]) && $params[$key] != 0) {
                    return Api::json(config('code.params_error'), $key.trans('msg.params_not_null'));
                }
                //status只允许0 删除 2 冻结  其他则视为参数错误
                if($params['status'] && !in_array($params['status'], array(0,2))){
                    return Api::json(config('code.params_error'), trans('msg.params_error'));
                }
            }

            $res = PrizeService::prizeSoldOut($params);

            return Api::json($res['code'], $res['msg'], $res['data']);
        }catch(\Exception $e) {
            return Api::serviceError($e);
        }
    }

    /**
     * 默认宝箱数据生成
     * @param Request $request
     * @return string
     */
    public function postBoxDefault(Request $request){
        $params = $request->all();
        if(empty($params['activity_id']) || empty($params['corp_id'])){
            return Api::json(config('code.params_error'), trans('msg.params_error'));
        }

        $activityInfo = ActivityService::getActivityInfo($params['activity_id']);
        if(!$activityInfo){
            return Api::json(config('code.fail'), trans('msg.activity_not_exist'));
        }

        //获取活动宝箱信息
        $res = PrizeService::getLotteryBoxs($params);
        if(empty($res['data'])){
            //插入默认宝箱
            $result = PrizeService::defaultBox($params, true);
            if($result['code'] == 0){
                return Api::json($result['code'], $result['msg'], $result['data']);
            } else {
                return Api::json($result['code'], $result['msg']);
            }
        } else {
            return Api::json(config('code.success'), trans('msg.success'), $res['data']);
        }
    }

//    /**
//     * 宝箱状态修改
//     * @param Request $request
//     * @return string
//     */
//    public function postBoxStatus(Request $request){
//        $params = $request->all();
//        $keys = array('activity_id', 'lottery_level', 'corp_id', 'status');
//        foreach ($keys as $key) {
//            if (empty($params[$key]) && $params[$key] != 0) {
//                return Api::json(config('code.params_error'), $key.trans('msg.params_not_null'));
//            }
//            //status只允许0 删除 2 冻结  其他则视为参数错误
//            if($params['status'] && !in_array($params['status'], array(0,1))){
//                return Api::json(config('code.params_error'), trans('msg.params_error'));
//            }
//        }
//
//        $box = LotteryBoxs::where('activity_id', $params['activity_id'])
//            ->where('corp_id',$params['corp_id'])
//            ->where('lottery_level', $params['lottery_level'])->first();
//
//        if(!$box){
//            return Api::json(config('code.fail'), '宝箱不存在');
//        }
//        $res = LotteryBoxs::where('activity_id', $params['activity_id'])
//                            ->where('corp_id',$params['corp_id'])
//                            ->where('lottery_level', $params['lottery_level'])
//                            ->update(['status'=>$params['status'], 'update_time'=>time()]);
//        if($res){
//            return Api::json(config('code.success'), trans('msg.success'));
//        } else {
//            Api::json(config('code.sql_error'), trans('msg.sql_error'));
//        }
//    }
}
?>